package controller;

import javafx.application.Application;
import javafx.scene.*;
import javafx.scene.input.KeyEvent;
import javafx.stage.Stage;
import view.*;

public class Main extends Application {
	@Override
	public void start(Stage stage) {

		// init - some window settings
		stage.setMaximized(true); // maximized window
		stage.setTitle("Chess3D - Tuna Acikbas & Olivier Pillods"); // title

		// init - camera
		CustomCamera camera = new CustomCamera(1, 1000, 70); // create a camera and some settings

		// init - scene, main container
		Group group = new Group(); // will contain all the elements "to show" on scene
		CustomScene scene = new CustomScene(group, camera.getCamera(), SceneAntialiasing.BALANCED);

		// event - camera movement with mouse
		camera.initMouseControl(scene.get()); // allow user to move camera with mouse, with some constraints

		// event - camera manual zoom (Z and S)
		stage.addEventHandler(KeyEvent.KEY_PRESSED, event -> {
			switch (event.getCode()) {
				case Z -> camera.getCamera().translateZProperty().set(camera.getCamera().getTranslateZ() + 10);
				case S -> camera.getCamera().translateZProperty().set(camera.getCamera().getTranslateZ() - 10);
			}
		});

		// init - materials and shaders
		CustomMaterial material = new CustomMaterial(); // prepare all the 3D materials (shaders)

		// init - all lights
		CustomLight light = new CustomLight(); // setups different custom lights
		light.addAllToScene(group); // adds all the lights to scene

		// init - import all 3D models from .obj files
		Custom3dModel model = new Custom3dModel();

		// init - create a chessboard of 8x8, and all 3d pieces
		BoardView boardView = new BoardView(model, material);
		boardView.addAllToScene(group); // adds the board and the pieces to scene

		// init - creates a wooden desk
		Desk desk = new Desk(material);
		desk.addAllToScene(group); // adds the desk to scene

		// start - links scene to application and shows application
		stage.setScene(scene.get());
		stage.show();
	}

	public static void main(String[] args) {
		launch();
	}
}