package model;

public class Board {

	public static final int PAWN = 0, ROOK = 1, KNIGHT = 2, BISHOP = 3, QUEEN = 4, KING = 5;

	private Piece[] pieces;

	public Board() {
		pieces = new Piece[64];
		// initialisation of the list of pieces
		for(int i = 0 ; i < 64 ; i++) {
			pieces[i] = null;
		}
		int y = 0;
		for(int color = Piece.WHITE ; color == Piece.WHITE || color == Piece.BLACK ; color++) {
			// placement of pawns
			if(color == Piece.WHITE) { y = 2; }
			else { y = 7; }
			for(int x = Position.a ; x <= Position.h ; x++) {
				createPiece(x, y, color, PAWN); // fills line 2 and line 7 with pawns
			}
			// placement of rook, knight, bishop, queen, king - line 1 and line 8
			if(color == Piece.WHITE) { y = 1; }
			else { y = 8; }
			createPiece(Position.a, y, color, ROOK);
			createPiece(Position.b, y, color, KNIGHT);
			createPiece(Position.c, y, color, BISHOP);
			createPiece(Position.d, y, color, QUEEN);
			createPiece(Position.e, y, color, KING);
			createPiece(Position.f, y, color, BISHOP);
			createPiece(Position.g, y, color, KNIGHT);
			createPiece(Position.h, y, color, ROOK);
		}
	}

	public void set(Piece piece) {
		pieces[piece.getPosition().getID()] = piece;
	}
	public void createPiece(int x, int y, int color, int type) {
		switch(type) {
			case PAWN -> set(new Pawn(new Position(x, y), color));
			//case ROOK -> set(new Rook(new Position(x, y), color));
			//case KNIGHT -> set(new Knight(new Position(x, y), color));
			//case BISHOP -> set(new Bishop(new Position(x, y), color));
			//case QUEEN -> set(new Queen(new Position(x, y), color));
			//case KING -> set(new King(new Position(x, y), color));
		}
	}

	public boolean isFree(Position p) {
		return (pieces[p.getID()] == null);
	}
	public boolean isBlack(Position p) {
		return (pieces[p.getID()].getColor() == Piece.BLACK);
	}

	public boolean isWhite(Position p) {
		return (pieces[p.getID()].getColor() == Piece.WHITE);
	}
	/*public boolean isKing(Position p) {
		return (pieces[p.getID()].getClass() == King.class);
	}*/
}
